#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
# grabslides : multipurpose frame grabber
#
# (c) 2005-2009 Jerome Alet <alet@librelogiciel.com>
# (c) 2009 University of New-Caledonia
# (c) 2005, 2006 Faculty of Medecine, University of Nice-Sophia Antipolis
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
#
#

"""This module defines the class for file based frame grabbers."""

import os
import urlparse

import pygst
pygst.require("0.10")
import gst

from grabslides import framegrabber

class FrameGrabber(framegrabber.BaseFrameGrabber) :
    """A class to grab frames from video files."""
    def __init__(self, parent, url, every, threshold) :
        """Initializes the frame grabber."""
        parsed = urlparse.urlparse(url)
        if parsed[0] in ("file", "") :
            filename = parsed[2]
            if not os.path.exists(filename) :
                raise ValueError, "File does not exist : %(filename)s" % locals()
            source = 'filesrc location="%(filename)s"' % locals()
            framegrabber.BaseFrameGrabber.__init__(self, parent,
                                                         url,
                                                         every,
                                                         threshold,
                                                         source)
        else :
            raise ValueError, "Incorrect parameter '%(url)s' for file frame grabber." % locals()

    def seekToNextFrame(self, interval) :
        """Seeks stream to next position."""
        if self.pipeline is None :
            return False
        else :
            return self.pipeline.seek(1.0,
                                      gst.FORMAT_TIME,
                                      gst.SEEK_FLAG_FLUSH | gst.SEEK_FLAG_KEY_UNIT,
                                      gst.SEEK_TYPE_CUR,
                                      interval * gst.SECOND,
                                      gst.SEEK_TYPE_NONE, 0)
